@@ -2,6 +2,7 @@
 
 use std::collections::HashMap;
 use std::ffi::OsString;
+use std::fmt::{Display, Formatter};
 use std::io;
 use std::io::{stdin, BufRead, BufReader};
 use std::path::PathBuf;
@@ -31,6 +32,17 @@ impl OutputFormat {
     }
 }
 
+impl Display for OutputFormat {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        match self {
+            OutputFormat::Default => f.pad("default"),
+            OutputFormat::Fdupes => f.pad("fdupes"),
+            OutputFormat::Csv => f.pad("csv"),
+            OutputFormat::Json => f.pad("json"),
+        }
+    }
+}
+
 impl FromStr for OutputFormat {
     type Err = String;
 
